%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function CBA_Env(L,E,I,R,wg,wq)
% Patterns loading for maximum effects, returning envelopes of bending
% moment and shear
gammaGmax = 1.4; gammaGmin = 0.9;
gammaQmax = 1.6; gammaQmin = 0.0;

N = length(L); 
[gr, gc] = size(wg); [qr, qc] = size(wq);
w = zeros(gr+qr,max(gc,qc));
wmax = w; wmin = w;

wmax(1:gr,:) = wg; 
wmax(1:gr,3) = gammaGmax.*wmax(1:gr,3);
wmax((gr+1):(gr+qr),:) = wq; 
wmax((gr+1):(gr+qr),3) = gammaQmax.*wmax((gr+1):(gr+qr),3);

wmin(1:gr,:) = wg; 
wmin(1:gr,3) = gammaGmin.*wmin(1:gr,3);
wmin((gr+1):(gr+qr),:) = wq; 
wmin((gr+1):(gr+qr),3) = gammaQmin.*wmin((gr+1):(gr+qr),3);

% Maximum support hogging and reaction
n_max_hog = max(N-1,0);
for i = 1:n_max_hog
    w = wmin;
    for j = 1:(gr+qr)
        if wmax(j,1) == i | wmax(j,1) == i+1
            w(j,:) = wmax(j,:);
        end
    end
    CBA(L,E,I,R,w,'b')
end

% odd numbered spans
w = wmax;
for i = 2:2:N
    for j = 1:(gr+qr)
        if wmax(j,1) == i; w(j,:) = wmin(j,:); end;
    end
end
CBA(L,E,I,R,w,'r')

% even numbered spans
w = wmin;
for i = 2:2:N
    for j = 1:(gr+qr)
        if wmin(j,1) == i; w(j,:) = wmax(j,:); end;
    end
end
CBA(L,E,I,R,w,'g')

% max load
CBA(L,E,I,R,wmax,'k')
